package main

import (
	"go.wit.com/lib/protobuf/gitpb"
	"go.wit.com/log"
)

// this will make go.mod and go.sum files, but you have to
// have the files in .gitignore for now
func doSmart(repo *gitpb.Repo) error {
	// if the repo has go.mod in the repo...
	if err := repo.RepoIgnoresGoMod(); err != nil {
		log.Info("go-mod-clean can not run on this repo", repo.GetGoPath())
		log.Info("go.mod and go.sum must be git metadata to continue")
		repo.ParseGoSum()
		return nil
	}

	// erase the go.mod and go.sum files
	eraseGoMod(repo)

	// try to restore from the git metadata
	cname := repo.GetCurrentBranchName()
	if err := repo.AutogenRestore(cname); err == nil {
		log.Info(repo.GetGoPath(), "files were restored ok from git metadata (notes)")
		configSave = true
		return nil
	}

	// attempt to restore from ~/go/pkg/mod/
	if err := restoreFromGoPkg(repo); err == nil {
		configSave = true
		return nil
	}

	// actually will re-create go.sum and go.mod now
	if err := redoGoMod(repo); err != nil {
		return err
	}

	// the first time, it'll attempt to fix some stuff
	cleanGoDepsCheckOk(repo)
	// try to trim junk
	if err := trimGoSum(repo); err != nil {
		return err
	}
	repo.ParseGoSum()

	// everything worked more or less
	configSave = true
	return nil
}
